@@ -74,11 +74,7 @@ class TestCommandDecoder < Test::Unit::TestCase
     fqdn = "delian"
     @decoder.decode(@encoder.encode_helo(fqdn))
     @decoder.end_decode
-    if decoded_fqdn.respond_to?(:encoding)
-      assert_equal([fqdn, Encoding::ASCII_8BIT], [decoded_fqdn, decoded_fqdn.encoding])
-    else
-      assert_equal(fqdn, decoded_fqdn)
-    end
+    assert_equal([fqdn, Encoding::ASCII_8BIT], [decoded_fqdn, decoded_fqdn.encoding])
   end
 
   def test_envelope_from
@@ -90,11 +86,7 @@ class TestCommandDecoder < Test::Unit::TestCase
     from = "kou+sender@cozmixng.org"
     @decoder.decode(@encoder.encode_envelope_from(from))
     @decoder.end_decode
-    if decoded_from.respond_to?(:encoding)
-      assert_equal([from, Encoding::ASCII_8BIT], [decoded_from, decoded_from.encoding])
-    else
-      assert_equal(from, decoded_from)
-    end
+    assert_equal([from, Encoding::ASCII_8BIT], [decoded_from, decoded_from.encoding])
   end
 
   def test_envelope_recipient
@@ -106,11 +98,7 @@ class TestCommandDecoder < Test::Unit::TestCase
     to = "kou+sender@cozmixng.org"
     @decoder.decode(@encoder.encode_envelope_recipient(to))
     @decoder.end_decode
-    if decoded_to.respond_to?(:encoding)
-      assert_equal([to, Encoding::ASCII_8BIT], [decoded_to, decoded_to.encoding])
-    else
-      assert_equal(to, decoded_to)
-    end
+    assert_equal([to, Encoding::ASCII_8BIT], [decoded_to, decoded_to.encoding])
   end
 
   def test_data
@@ -136,13 +124,8 @@ class TestCommandDecoder < Test::Unit::TestCase
     value = "value"
     @decoder.decode(@encoder.encode_header(name, value))
     @decoder.end_decode
-    if name.respond_to?(:encoding)
-      assert_equal([name, Encoding::ASCII_8BIT, value, Encoding::ASCII_8BIT],
-                   [decoded_name, decoded_name.encoding, decoded_value, decoded_value.encoding])
-    else
-      assert_equal([name, value],
-                   [decoded_name, decoded_value])
-    end
+    assert_equal([name, Encoding::ASCII_8BIT, value, Encoding::ASCII_8BIT],
+                 [decoded_name, decoded_name.encoding, decoded_value, decoded_value.encoding])
   end
 
   def test_end_of_header
@@ -228,10 +211,6 @@ class TestCommandDecoder < Test::Unit::TestCase
     command = "UNKNOWN COMMAND WITH ARGUMENT"
     @decoder.decode(@encoder.encode_unknown(command))
     @decoder.end_decode
-    if decoded_command.respond_to?(:encoding)
-      assert_equal([command, Encoding::ASCII_8BIT], [decoded_command, decoded_command.encoding])
-    else
-      assert_equal(command, decoded_command)
-    end
+    assert_equal([command, Encoding::ASCII_8BIT], [decoded_command, decoded_command.encoding])
   end
 end
