@@ -339,8 +339,9 @@ cut_setup (void)
         milter_client_set_n_workers(client, n_workers);
     }
     loop_run_count = 0;
-    loop = milter_client_get_event_loop(client);
-    g_object_ref(loop);
+    loop = milter_client_create_event_loop(client, TRUE);
+    milter_client_set_event_loop(client, loop);
+    g_object_unref(loop);
     milter_event_loop_set_custom_run_func(loop, loop_run);
     setup_client_signals();
     server = NULL;
@@ -411,19 +412,16 @@ cut_teardown (void)
     if (idle_shutdown_id > 0)
         milter_event_loop_remove(loop, idle_shutdown_id);
 
-    if (client)
-        g_object_unref(client);
     if (server)
         g_object_unref(server);
+    if (client)
+        g_object_unref(client);
 
     if (decoder)
         g_object_unref(decoder);
     if (encoder)
         g_object_unref(encoder);
 
-    if (loop)
-        g_object_unref(loop);
-
     if (option)
         g_object_unref(option);
     if (negotiate_option)
